@@ -15,6 +15,7 @@ from src.mb_cruise_migration.processors.cruise_processor import CruiseProcessor
 from src.mb_cruise_migration.processors.transfer_station import TransferStation
 from src.mb_cruise_migration.logging.migration_report import MigrationReport
 from src.mb_cruise_migration.processors.mb_processor import MbProcessor
+from src.mb_cruise_migration.utility.common import strip_none
 
 
 class Migrator(object):
@@ -86,7 +87,7 @@ class Migrator(object):
     @staticmethod
     def prepare_shipment(mb_crates) -> [CruiseCargo]:
         stations = [TransferStation(crate) for crate in mb_crates]
-        cruise_cargos = [station.transfer() for station in stations]
+        cruise_cargos = strip_none([station.transfer() for station in stations])
         return [cargo for cruise_cargo in cruise_cargos for cargo in cruise_cargo]  # flatten
 
     @staticmethod
@@ -97,7 +98,7 @@ class Migrator(object):
     def end_migration():
         MigrationLog.log_end()
         MigrationReport.end = datetime.now()
-        MigrationReport.final_report()
+        MigrationReport.migration_final_report()
 
     @staticmethod
     def fail_migration(context, exception: Exception):
