@@ -53,11 +53,13 @@ class MbProcessor(object):
         survey_crate = MbSurveyCrate(survey, survey_reference, survey_shape)
 
         files = self.mb_service.get_survey_files(survey.ngdc_id)
+        if not files:
+            self.__skip_survey(survey.survey_name, "no associated files found for survey in mb schema.")
+            return None
         files = FileFilter.filter_invalid_files(files)
         files, file_removed = FileFilter.filter_files_not_configured_for_migration(files)
         if file_removed > 0:  # cancel survey migration if any files are filtered.
-            MigrationLog.log_skipped_survey(survey.survey_name)
-            MigrationReport.add_skipped_survey(survey.survey_name)
+            self.__skip_survey(survey.survey_name, f"at least {file_removed} files were filtered due to being marked for non-migration in config.")
             return None
 
         files = FileLabeler.label(files)
@@ -106,4 +108,9 @@ class MbProcessor(object):
 
             MigrationProperties.SURVEY_QUERY = f"SELECT * FROM MB.SURVEY WHERE {where_conditions}"
         else:
-            MigrationProperties.SURVEY_QUERY = MigrationProperties.manifest.default_query
\ No newline at end of file
+            MigrationProperties.SURVEY_QUERY = MigrationProperties.manifest.default_query
+
+    @staticmethod
+    def __skip_survey(survey_name: str, message):
+        MigrationLog.log_skipped_survey(survey_name, message)
+        MigrationReport.add_skipped_survey(survey_name)
\ No newline at end of file
