@@ -5,11 +5,13 @@ from src.mb_cruise_migration.framework.resolvers.file_format_resolver import FFL
 from src.mb_cruise_migration.framework.resolvers.file_type_resolver import FTLookup
 from src.mb_cruise_migration.framework.resolvers.version_description_resolver import VDLookup
 from src.mb_cruise_migration.framework.consts.const_initializer import ConstInitializer
+from src.mb_cruise_migration.logging.migration_log import MigrationLog
 from src.mb_cruise_migration.migration_properties import MigrationProperties
 
 
 class TestConstInitializer(unittest.TestCase):
     MigrationProperties("config_test.yaml")
+    MigrationLog()
 
     def test_cruise_const_setup(self):
         try:
