@@ -1,4 +1,5 @@
 import unittest
+import datetime
 
 
 class TestScratch(unittest.TestCase):
@@ -19,3 +20,13 @@ class TestScratch(unittest.TestCase):
         except RuntimeWarning as w:
             warning = str(w)
             self.assertEqual(message, warning)
+
+    def test_date_formatting(self):
+        date = datetime.datetime(2020, 5, 18, 1, 2, 4).isoformat()
+        print(date)
+
+        # timestamp = "04-SEP-19"
+        # timestamp = datetime.datetime.strptime()
+        # date_only = timestamp.strftime('%d-%b-%y')
+        # print(date_only)
+
